@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
+from distutils import util
 import os
 import re
-from typing import Callable, Dict, Sequence, Tuple, Type, Union
+from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import client_options as client_options_lib  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from grafeas.grafeas_v1.services.grafeas import pagers
 from grafeas.grafeas_v1.types import attestation
 from grafeas.grafeas_v1.types import build
@@ -43,8 +43,7 @@ from grafeas.grafeas_v1.types import image
 from grafeas.grafeas_v1.types import package
 from grafeas.grafeas_v1.types import upgrade
 from grafeas.grafeas_v1.types import vulnerability
-
-from .transports.base import GrafeasTransport
+from .transports.base import GrafeasTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import GrafeasGrpcTransport
 from .transports.grpc_asyncio import GrafeasGrpcAsyncIOTransport
 
@@ -62,7 +61,7 @@ class GrafeasClientMeta(type):
     _transport_registry["grpc_asyncio"] = GrafeasGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[GrafeasTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -101,7 +100,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -128,37 +128,129 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         return api_endpoint.replace(".googleapis.com", ".mtls.googleapis.com")
 
-    DEFAULT_ENDPOINT = "containeranalysis.googleapis.com"
-    DEFAULT_MTLS_ENDPOINT = _get_default_mtls_endpoint.__func__(  # type: ignore
-        DEFAULT_ENDPOINT
-    )
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            GrafeasClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
+    @property
+    def transport(self) -> GrafeasTransport:
+        """Returns the transport used by the client instance.
+
+        Returns:
+            GrafeasTransport: The transport used by the client
+                instance.
+        """
+        return self._transport
 
     @staticmethod
     def note_path(project: str, note: str,) -> str:
-        """Return a fully-qualified note string."""
+        """Returns a fully-qualified note string."""
         return "projects/{project}/notes/{note}".format(project=project, note=note,)
 
     @staticmethod
     def parse_note_path(path: str) -> Dict[str, str]:
-        """Parse a note path into its component segments."""
+        """Parses a note path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/notes/(?P<note>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
     def occurrence_path(project: str, occurrence: str,) -> str:
-        """Return a fully-qualified occurrence string."""
+        """Returns a fully-qualified occurrence string."""
         return "projects/{project}/occurrences/{occurrence}".format(
             project=project, occurrence=occurrence,
         )
 
     @staticmethod
     def parse_occurrence_path(path: str) -> Dict[str, str]:
-        """Parse a occurrence path into its component segments."""
+        """Parses a occurrence path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/occurrences/(?P<occurrence>.+?)$", path
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def project_path(project: str,) -> str:
+        """Returns a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
+
+    @staticmethod
+    def parse_project_path(path: str) -> Dict[str, str]:
+        """Parses a project path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_billing_account_path(billing_account: str,) -> str:
+        """Returns a fully-qualified billing_account string."""
+        return "billingAccounts/{billing_account}".format(
+            billing_account=billing_account,
+        )
+
+    @staticmethod
+    def parse_common_billing_account_path(path: str) -> Dict[str, str]:
+        """Parse a billing_account path into its component segments."""
+        m = re.match(r"^billingAccounts/(?P<billing_account>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_folder_path(folder: str,) -> str:
+        """Returns a fully-qualified folder string."""
+        return "folders/{folder}".format(folder=folder,)
+
+    @staticmethod
+    def parse_common_folder_path(path: str) -> Dict[str, str]:
+        """Parse a folder path into its component segments."""
+        m = re.match(r"^folders/(?P<folder>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_organization_path(organization: str,) -> str:
+        """Returns a fully-qualified organization string."""
+        return "organizations/{organization}".format(organization=organization,)
+
+    @staticmethod
+    def parse_common_organization_path(path: str) -> Dict[str, str]:
+        """Parse a organization path into its component segments."""
+        m = re.match(r"^organizations/(?P<organization>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_project_path(project: str,) -> str:
+        """Returns a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
+
+    @staticmethod
+    def parse_common_project_path(path: str) -> Dict[str, str]:
+        """Parse a project path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_location_path(project: str, location: str,) -> str:
+        """Returns a fully-qualified location string."""
+        return "projects/{project}/locations/{location}".format(
+            project=project, location=location,
+        )
+
+    @staticmethod
+    def parse_common_location_path(path: str) -> Dict[str, str]:
+        """Parse a location path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
+        return m.groupdict() if m else {}
+
     def __init__(self, *, transport: Union[str, GrafeasTransport] = None,) -> None:
         """Instantiate the grafeas client.
 
@@ -190,15 +282,15 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Gets the specified occurrence.
 
         Args:
-            request (:class:`~.grafeas.GetOccurrenceRequest`):
+            request (grafeas.grafeas_v1.types.GetOccurrenceRequest):
                 The request object. Request to get an occurrence.
-            name (:class:`str`):
+            name (str):
                 The name of the occurrence in the form of
                 ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -206,7 +298,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.Occurrence:
+            grafeas.grafeas_v1.types.Occurrence:
                 An instance of an analysis type that
                 has been found on a resource.
 
@@ -227,10 +319,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.GetOccurrenceRequest):
             request = grafeas.GetOccurrenceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -263,20 +353,20 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Lists occurrences for the specified project.
 
         Args:
-            request (:class:`~.grafeas.ListOccurrencesRequest`):
+            request (grafeas.grafeas_v1.types.ListOccurrencesRequest):
                 The request object. Request to list occurrences.
-            parent (:class:`str`):
+            parent (str):
                 The name of the project to list occurrences for in the
                 form of ``projects/[PROJECT_ID]``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            filter (:class:`str`):
+            filter (str):
                 The filter expression.
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -284,7 +374,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListOccurrencesPager:
+            grafeas.grafeas_v1.services.grafeas.pagers.ListOccurrencesPager:
                 Response for listing occurrences.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -307,10 +397,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.ListOccurrencesRequest):
             request = grafeas.ListOccurrencesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if filter is not None:
@@ -352,15 +440,15 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         is no longer applicable for the given resource.
 
         Args:
-            request (:class:`~.grafeas.DeleteOccurrenceRequest`):
+            request (grafeas.grafeas_v1.types.DeleteOccurrenceRequest):
                 The request object. Request to delete an occurrence.
-            name (:class:`str`):
+            name (str):
                 The name of the occurrence in the form of
                 ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -383,10 +471,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.DeleteOccurrenceRequest):
             request = grafeas.DeleteOccurrenceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -418,21 +504,21 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Creates a new occurrence.
 
         Args:
-            request (:class:`~.grafeas.CreateOccurrenceRequest`):
+            request (grafeas.grafeas_v1.types.CreateOccurrenceRequest):
                 The request object. Request to create a new occurrence.
-            parent (:class:`str`):
+            parent (str):
                 The name of the project in the form of
                 ``projects/[PROJECT_ID]``, under which the occurrence is
                 to be created.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            occurrence (:class:`~.grafeas.Occurrence`):
+            occurrence (grafeas.grafeas_v1.types.Occurrence):
                 The occurrence to create.
                 This corresponds to the ``occurrence`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -440,7 +526,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.Occurrence:
+            grafeas.grafeas_v1.types.Occurrence:
                 An instance of an analysis type that
                 has been found on a resource.
 
@@ -461,10 +547,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.CreateOccurrenceRequest):
             request = grafeas.CreateOccurrenceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if occurrence is not None:
@@ -499,23 +583,24 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Creates new occurrences in batch.
 
         Args:
-            request (:class:`~.grafeas.BatchCreateOccurrencesRequest`):
+            request (grafeas.grafeas_v1.types.BatchCreateOccurrencesRequest):
                 The request object. Request to create occurrences in
                 batch.
-            parent (:class:`str`):
+            parent (str):
                 The name of the project in the form of
                 ``projects/[PROJECT_ID]``, under which the occurrences
                 are to be created.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            occurrences (:class:`Sequence[~.grafeas.Occurrence]`):
+            occurrences (Sequence[grafeas.grafeas_v1.types.Occurrence]):
                 The occurrences to create. Max
                 allowed length is 1000.
+
                 This corresponds to the ``occurrences`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -523,7 +608,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.BatchCreateOccurrencesResponse:
+            grafeas.grafeas_v1.types.BatchCreateOccurrencesResponse:
                 Response for creating occurrences in
                 batch.
 
@@ -544,10 +629,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.BatchCreateOccurrencesRequest):
             request = grafeas.BatchCreateOccurrencesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if occurrences is not None:
@@ -575,7 +658,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         name: str = None,
         occurrence: grafeas.Occurrence = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -583,25 +666,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Updates the specified occurrence.
 
         Args:
-            request (:class:`~.grafeas.UpdateOccurrenceRequest`):
+            request (grafeas.grafeas_v1.types.UpdateOccurrenceRequest):
                 The request object. Request to update an occurrence.
-            name (:class:`str`):
+            name (str):
                 The name of the occurrence in the form of
                 ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            occurrence (:class:`~.grafeas.Occurrence`):
+            occurrence (grafeas.grafeas_v1.types.Occurrence):
                 The updated occurrence.
                 This corresponds to the ``occurrence`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 The fields to update.
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -609,7 +692,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.Occurrence:
+            grafeas.grafeas_v1.types.Occurrence:
                 An instance of an analysis type that
                 has been found on a resource.
 
@@ -630,10 +713,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.UpdateOccurrenceRequest):
             request = grafeas.UpdateOccurrenceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if occurrence is not None:
@@ -671,16 +752,16 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         belongs to a provider project.
 
         Args:
-            request (:class:`~.grafeas.GetOccurrenceNoteRequest`):
+            request (grafeas.grafeas_v1.types.GetOccurrenceNoteRequest):
                 The request object. Request to get the note to which the
                 specified occurrence is attached.
-            name (:class:`str`):
+            name (str):
                 The name of the occurrence in the form of
                 ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -688,7 +769,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.Note:
+            grafeas.grafeas_v1.types.Note:
                 A type of analysis that can be done
                 for a resource.
 
@@ -709,10 +790,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.GetOccurrenceNoteRequest):
             request = grafeas.GetOccurrenceNoteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -744,15 +823,15 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Gets the specified note.
 
         Args:
-            request (:class:`~.grafeas.GetNoteRequest`):
+            request (grafeas.grafeas_v1.types.GetNoteRequest):
                 The request object. Request to get a note.
-            name (:class:`str`):
+            name (str):
                 The name of the note in the form of
                 ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -760,7 +839,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.Note:
+            grafeas.grafeas_v1.types.Note:
                 A type of analysis that can be done
                 for a resource.
 
@@ -781,10 +860,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.GetNoteRequest):
             request = grafeas.GetNoteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -817,20 +894,20 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Lists notes for the specified project.
 
         Args:
-            request (:class:`~.grafeas.ListNotesRequest`):
+            request (grafeas.grafeas_v1.types.ListNotesRequest):
                 The request object. Request to list notes.
-            parent (:class:`str`):
+            parent (str):
                 The name of the project to list notes for in the form of
                 ``projects/[PROJECT_ID]``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            filter (:class:`str`):
+            filter (str):
                 The filter expression.
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -838,7 +915,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListNotesPager:
+            grafeas.grafeas_v1.services.grafeas.pagers.ListNotesPager:
                 Response for listing notes.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -861,10 +938,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.ListNotesRequest):
             request = grafeas.ListNotesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if filter is not None:
@@ -904,15 +979,15 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Deletes the specified note.
 
         Args:
-            request (:class:`~.grafeas.DeleteNoteRequest`):
+            request (grafeas.grafeas_v1.types.DeleteNoteRequest):
                 The request object. Request to delete a note.
-            name (:class:`str`):
+            name (str):
                 The name of the note in the form of
                 ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -935,10 +1010,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.DeleteNoteRequest):
             request = grafeas.DeleteNoteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -971,26 +1044,26 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Creates a new note.
 
         Args:
-            request (:class:`~.grafeas.CreateNoteRequest`):
+            request (grafeas.grafeas_v1.types.CreateNoteRequest):
                 The request object. Request to create a new note.
-            parent (:class:`str`):
+            parent (str):
                 The name of the project in the form of
                 ``projects/[PROJECT_ID]``, under which the note is to be
                 created.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            note_id (:class:`str`):
+            note_id (str):
                 The ID to use for this note.
                 This corresponds to the ``note_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            note (:class:`~.grafeas.Note`):
+            note (grafeas.grafeas_v1.types.Note):
                 The note to create.
                 This corresponds to the ``note`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -998,7 +1071,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.Note:
+            grafeas.grafeas_v1.types.Note:
                 A type of analysis that can be done
                 for a resource.
 
@@ -1019,10 +1092,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.CreateNoteRequest):
             request = grafeas.CreateNoteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if note_id is not None:
@@ -1059,22 +1130,23 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Creates new notes in batch.
 
         Args:
-            request (:class:`~.grafeas.BatchCreateNotesRequest`):
+            request (grafeas.grafeas_v1.types.BatchCreateNotesRequest):
                 The request object. Request to create notes in batch.
-            parent (:class:`str`):
+            parent (str):
                 The name of the project in the form of
                 ``projects/[PROJECT_ID]``, under which the notes are to
                 be created.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            notes (:class:`Sequence[~.grafeas.BatchCreateNotesRequest.NotesEntry]`):
+            notes (Sequence[grafeas.grafeas_v1.types.BatchCreateNotesRequest.NotesEntry]):
                 The notes to create. Max allowed
                 length is 1000.
+
                 This corresponds to the ``notes`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1082,7 +1154,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.BatchCreateNotesResponse:
+            grafeas.grafeas_v1.types.BatchCreateNotesResponse:
                 Response for creating notes in batch.
         """
         # Create or coerce a protobuf request object.
@@ -1101,10 +1173,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.BatchCreateNotesRequest):
             request = grafeas.BatchCreateNotesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if notes is not None:
@@ -1132,7 +1202,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         name: str = None,
         note: grafeas.Note = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1140,25 +1210,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         r"""Updates the specified note.
 
         Args:
-            request (:class:`~.grafeas.UpdateNoteRequest`):
+            request (grafeas.grafeas_v1.types.UpdateNoteRequest):
                 The request object. Request to update a note.
-            name (:class:`str`):
+            name (str):
                 The name of the note in the form of
                 ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            note (:class:`~.grafeas.Note`):
+            note (grafeas.grafeas_v1.types.Note):
                 The updated note.
                 This corresponds to the ``note`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 The fields to update.
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1166,7 +1236,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.grafeas.Note:
+            grafeas.grafeas_v1.types.Note:
                 A type of analysis that can be done
                 for a resource.
 
@@ -1187,10 +1257,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.UpdateNoteRequest):
             request = grafeas.UpdateNoteRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if note is not None:
@@ -1230,21 +1298,21 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         specified note.
 
         Args:
-            request (:class:`~.grafeas.ListNoteOccurrencesRequest`):
+            request (grafeas.grafeas_v1.types.ListNoteOccurrencesRequest):
                 The request object. Request to list occurrences for a
                 note.
-            name (:class:`str`):
+            name (str):
                 The name of the note to list occurrences for in the form
                 of ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            filter (:class:`str`):
+            filter (str):
                 The filter expression.
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1252,7 +1320,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListNoteOccurrencesPager:
+            grafeas.grafeas_v1.services.grafeas.pagers.ListNoteOccurrencesPager:
                 Response for listing occurrences for
                 a note.
                 Iterating over this object will yield
@@ -1276,10 +1344,8 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         # there are no flattened fields.
         if not isinstance(request, grafeas.ListNoteOccurrencesRequest):
             request = grafeas.ListNoteOccurrencesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if filter is not None:
@@ -1309,11 +1375,11 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
 
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution("grafeas",).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
 
 __all__ = ("GrafeasClient",)
