@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,27 +13,37 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
-from google.protobuf import empty_pb2 as empty  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 from grafeas.grafeas_v1.types import grafeas
 
-
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution("grafeas",).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
 
 
 class GrafeasTransport(abc.ABC):
@@ -42,20 +51,25 @@ class GrafeasTransport(abc.ABC):
 
     AUTH_SCOPES = ()
 
+    DEFAULT_HOST: str = ""
+
     def __init__(
         self,
         *,
-        host: str = "",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -64,39 +78,79 @@ class GrafeasTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
+                your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
+        # Save the scopes.
+        self._scopes = scopes or self.AUTH_SCOPES
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials is service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages()
+    # TODO(busunkim): This method is in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-auth is increased.
 
-    def _prep_wrapped_messages(self):
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
+
+    def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.get_occurrence: gapic_v1.method.wrap_method(
@@ -106,11 +160,13 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.list_occurrences: gapic_v1.method.wrap_method(
                 self.list_occurrences,
@@ -119,11 +175,13 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.delete_occurrence: gapic_v1.method.wrap_method(
                 self.delete_occurrence,
@@ -132,22 +190,24 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.create_occurrence: gapic_v1.method.wrap_method(
-                self.create_occurrence, default_timeout=30.0, client_info=_client_info,
+                self.create_occurrence, default_timeout=30.0, client_info=client_info,
             ),
             self.batch_create_occurrences: gapic_v1.method.wrap_method(
                 self.batch_create_occurrences,
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.update_occurrence: gapic_v1.method.wrap_method(
-                self.update_occurrence, default_timeout=30.0, client_info=_client_info,
+                self.update_occurrence, default_timeout=30.0, client_info=client_info,
             ),
             self.get_occurrence_note: gapic_v1.method.wrap_method(
                 self.get_occurrence_note,
@@ -156,11 +216,13 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.get_note: gapic_v1.method.wrap_method(
                 self.get_note,
@@ -169,11 +231,13 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.list_notes: gapic_v1.method.wrap_method(
                 self.list_notes,
@@ -182,11 +246,13 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.delete_note: gapic_v1.method.wrap_method(
                 self.delete_note,
@@ -195,20 +261,22 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.create_note: gapic_v1.method.wrap_method(
-                self.create_note, default_timeout=30.0, client_info=_client_info,
+                self.create_note, default_timeout=30.0, client_info=client_info,
             ),
             self.batch_create_notes: gapic_v1.method.wrap_method(
-                self.batch_create_notes, default_timeout=30.0, client_info=_client_info,
+                self.batch_create_notes, default_timeout=30.0, client_info=client_info,
             ),
             self.update_note: gapic_v1.method.wrap_method(
-                self.update_note, default_timeout=30.0, client_info=_client_info,
+                self.update_note, default_timeout=30.0, client_info=client_info,
             ),
             self.list_note_occurrences: gapic_v1.method.wrap_method(
                 self.list_note_occurrences,
@@ -217,31 +285,32 @@ class GrafeasTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.ServiceUnavailable,
                     ),
+                    deadline=30.0,
                 ),
                 default_timeout=30.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
         }
 
     @property
     def get_occurrence(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.GetOccurrenceRequest],
-        typing.Union[grafeas.Occurrence, typing.Awaitable[grafeas.Occurrence]],
+        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_occurrences(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.ListOccurrencesRequest],
-        typing.Union[
-            grafeas.ListOccurrencesResponse,
-            typing.Awaitable[grafeas.ListOccurrencesResponse],
+        Union[
+            grafeas.ListOccurrencesResponse, Awaitable[grafeas.ListOccurrencesResponse]
         ],
     ]:
         raise NotImplementedError()
@@ -249,29 +318,29 @@ class GrafeasTransport(abc.ABC):
     @property
     def delete_occurrence(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.DeleteOccurrenceRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
     @property
     def create_occurrence(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.CreateOccurrenceRequest],
-        typing.Union[grafeas.Occurrence, typing.Awaitable[grafeas.Occurrence]],
+        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
     ]:
         raise NotImplementedError()
 
     @property
     def batch_create_occurrences(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.BatchCreateOccurrencesRequest],
-        typing.Union[
+        Union[
             grafeas.BatchCreateOccurrencesResponse,
-            typing.Awaitable[grafeas.BatchCreateOccurrencesResponse],
+            Awaitable[grafeas.BatchCreateOccurrencesResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -279,67 +348,61 @@ class GrafeasTransport(abc.ABC):
     @property
     def update_occurrence(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.UpdateOccurrenceRequest],
-        typing.Union[grafeas.Occurrence, typing.Awaitable[grafeas.Occurrence]],
+        Union[grafeas.Occurrence, Awaitable[grafeas.Occurrence]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_occurrence_note(
         self,
-    ) -> typing.Callable[
-        [grafeas.GetOccurrenceNoteRequest],
-        typing.Union[grafeas.Note, typing.Awaitable[grafeas.Note]],
+    ) -> Callable[
+        [grafeas.GetOccurrenceNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
     ]:
         raise NotImplementedError()
 
     @property
     def get_note(
         self,
-    ) -> typing.Callable[
-        [grafeas.GetNoteRequest],
-        typing.Union[grafeas.Note, typing.Awaitable[grafeas.Note]],
+    ) -> Callable[
+        [grafeas.GetNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
     ]:
         raise NotImplementedError()
 
     @property
     def list_notes(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.ListNotesRequest],
-        typing.Union[
-            grafeas.ListNotesResponse, typing.Awaitable[grafeas.ListNotesResponse]
-        ],
+        Union[grafeas.ListNotesResponse, Awaitable[grafeas.ListNotesResponse]],
     ]:
         raise NotImplementedError()
 
     @property
     def delete_note(
         self,
-    ) -> typing.Callable[
-        [grafeas.DeleteNoteRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+    ) -> Callable[
+        [grafeas.DeleteNoteRequest], Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]]
     ]:
         raise NotImplementedError()
 
     @property
     def create_note(
         self,
-    ) -> typing.Callable[
-        [grafeas.CreateNoteRequest],
-        typing.Union[grafeas.Note, typing.Awaitable[grafeas.Note]],
+    ) -> Callable[
+        [grafeas.CreateNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
     ]:
         raise NotImplementedError()
 
     @property
     def batch_create_notes(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.BatchCreateNotesRequest],
-        typing.Union[
+        Union[
             grafeas.BatchCreateNotesResponse,
-            typing.Awaitable[grafeas.BatchCreateNotesResponse],
+            Awaitable[grafeas.BatchCreateNotesResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -347,20 +410,19 @@ class GrafeasTransport(abc.ABC):
     @property
     def update_note(
         self,
-    ) -> typing.Callable[
-        [grafeas.UpdateNoteRequest],
-        typing.Union[grafeas.Note, typing.Awaitable[grafeas.Note]],
+    ) -> Callable[
+        [grafeas.UpdateNoteRequest], Union[grafeas.Note, Awaitable[grafeas.Note]]
     ]:
         raise NotImplementedError()
 
     @property
     def list_note_occurrences(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [grafeas.ListNoteOccurrencesRequest],
-        typing.Union[
+        Union[
             grafeas.ListNoteOccurrencesResponse,
-            typing.Awaitable[grafeas.ListNoteOccurrencesResponse],
+            Awaitable[grafeas.ListNoteOccurrencesResponse],
         ],
     ]:
         raise NotImplementedError()
